---
date: 2025-01-08
categories:
  - it
  - programming
tags:
  - Python
  - VScode
download: https://github.com/Harrix/harrix.dev-articles-2025/raw/main/uv-vscode-python/files/test-uv.zip
author: Anton Sergienko
author-email: anton.b.sergienko@gmail.com
license: CC BY 4.0
license-url: https://github.com/Harrix/harrix.dev/blob/main/LICENSE.md
permalink-source: https://github.com/Harrix/harrix.dev-articles-2025/blob/main/uv-vscode-python/uv-vscode-python.md
permalink: https://harrix.dev/ru/articles/2025/uv-vscode-python/
lang: ru
attribution:
  - author: Python Software Foundation
    author-site: https://www.python.org/psf/
    license: GNU General Public License
    license-url: https://en.wikipedia.org/wiki/GNU_General_Public_License
    permalink: https://commons.wikimedia.org/wiki/File:Python_logo_and_wordmark.svg
    permalink-date: 2021-08-01
    name: Python logo and wordmark.svg
---

# uv
